==> kubernetes-model-autoscaling-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ExternalMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExternalMetricStatusFluent<A extends ExternalMetricStatusFluent<A>> extends BaseFluent<A>{
  public ExternalMetricStatusFluent() {
  }
  
  public ExternalMetricStatusFluent(ExternalMetricStatus instance) {
    this.copyInstance(instance);
  }
  private Quantity currentAverageValue;
  private Quantity currentValue;
  private String metricName;
  private LabelSelectorBuilder metricSelector;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ExternalMetricStatus instance) {
    instance = (instance != null ? instance : new ExternalMetricStatus());
    if (instance != null) {
          this.withCurrentAverageValue(instance.getCurrentAverageValue());
          this.withCurrentValue(instance.getCurrentValue());
          this.withMetricName(instance.getMetricName());
          this.withMetricSelector(instance.getMetricSelector());
          this.withCurrentAverageValue(instance.getCurrentAverageValue());
          this.withCurrentValue(instance.getCurrentValue());
          this.withMetricName(instance.getMetricName());
          this.withMetricSelector(instance.getMetricSelector());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Quantity getCurrentAverageValue() {
    return this.currentAverageValue;
  }
  
  public A withCurrentAverageValue(Quantity currentAverageValue) {
    this.currentAverageValue = currentAverageValue;
    return (A) this;
  }
  
  public boolean hasCurrentAverageValue() {
    return this.currentAverageValue != null;
  }
  
  public A withNewCurrentAverageValue(String amount,String format) {
    return (A)withCurrentAverageValue(new Quantity(amount, format));
  }
  
  public A withNewCurrentAverageValue(String amount) {
    return (A)withCurrentAverageValue(new Quantity(amount));
  }
  
  public Quantity getCurrentValue() {
    return this.currentValue;
  }
  
  public A withCurrentValue(Quantity currentValue) {
    this.currentValue = currentValue;
    return (A) this;
  }
  
  public boolean hasCurrentValue() {
    return this.currentValue != null;
  }
  
  public A withNewCurrentValue(String amount,String format) {
    return (A)withCurrentValue(new Quantity(amount, format));
  }
  
  public A withNewCurrentValue(String amount) {
    return (A)withCurrentValue(new Quantity(amount));
  }
  
  public String getMetricName() {
    return this.metricName;
  }
  
  public A withMetricName(String metricName) {
    this.metricName = metricName;
    return (A) this;
  }
  
  public boolean hasMetricName() {
    return this.metricName != null;
  }
  
  public LabelSelector buildMetricSelector() {
    return this.metricSelector != null ? this.metricSelector.build() : null;
  }
  
  public A withMetricSelector(LabelSelector metricSelector) {
    this._visitables.remove(this.metricSelector);
    if (metricSelector != null) {
        this.metricSelector = new LabelSelectorBuilder(metricSelector);
        this._visitables.get("metricSelector").add(this.metricSelector);
    } else {
        this.metricSelector = null;
        this._visitables.get("metricSelector").remove(this.metricSelector);
    }
    return (A) this;
  }
  
  public boolean hasMetricSelector() {
    return this.metricSelector != null;
  }
  
  public MetricSelectorNested<A> withNewMetricSelector() {
    return new MetricSelectorNested(null);
  }
  
  public MetricSelectorNested<A> withNewMetricSelectorLike(LabelSelector item) {
    return new MetricSelectorNested(item);
  }
  
  public MetricSelectorNested<A> editMetricSelector() {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(null));
  }
  
  public MetricSelectorNested<A> editOrNewMetricSelector() {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public MetricSelectorNested<A> editOrNewMetricSelectorLike(LabelSelector item) {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalMetricStatusFluent that = (ExternalMetricStatusFluent) o;
    if (!java.util.Objects.equals(currentAverageValue, that.currentAverageValue)) return false;
    if (!java.util.Objects.equals(currentValue, that.currentValue)) return false;
    if (!java.util.Objects.equals(metricName, that.metricName)) return false;
    if (!java.util.Objects.equals(metricSelector, that.metricSelector)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(currentAverageValue,  currentValue,  metricName,  metricSelector,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (currentAverageValue != null) { sb.append("currentAverageValue:"); sb.append(currentAverageValue + ","); }
    if (currentValue != null) { sb.append("currentValue:"); sb.append(currentValue + ","); }
    if (metricName != null) { sb.append("metricName:"); sb.append(metricName + ","); }
    if (metricSelector != null) { sb.append("metricSelector:"); sb.append(metricSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetricSelectorNested<N> extends LabelSelectorFluent<MetricSelectorNested<N>> implements Nested<N>{
    MetricSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) ExternalMetricStatusFluent.this.withMetricSelector(builder.build());
    }
    
    public N endMetricSelector() {
      return and();
    }
    
  
  }

}

==> kubernetes-model-autoscaling-7.0.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ExternalMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExternalMetricStatusFluent<A extends ExternalMetricStatusFluent<A>> extends BaseFluent<A>{
  public ExternalMetricStatusFluent() {
  }
  
  public ExternalMetricStatusFluent(ExternalMetricStatus instance) {
    this.copyInstance(instance);
  }
  private Quantity currentAverageValue;
  private Quantity currentValue;
  private String metricName;
  private LabelSelectorBuilder metricSelector;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ExternalMetricStatus instance) {
    instance = (instance != null ? instance : new ExternalMetricStatus());
    if (instance != null) {
          this.withCurrentAverageValue(instance.getCurrentAverageValue());
          this.withCurrentValue(instance.getCurrentValue());
          this.withMetricName(instance.getMetricName());
          this.withMetricSelector(instance.getMetricSelector());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Quantity getCurrentAverageValue() {
    return this.currentAverageValue;
  }
  
  public A withCurrentAverageValue(Quantity currentAverageValue) {
    this.currentAverageValue = currentAverageValue;
    return (A) this;
  }
  
  public boolean hasCurrentAverageValue() {
    return this.currentAverageValue != null;
  }
  
  public A withNewCurrentAverageValue(String amount,String format) {
    return (A)withCurrentAverageValue(new Quantity(amount, format));
  }
  
  public A withNewCurrentAverageValue(String amount) {
    return (A)withCurrentAverageValue(new Quantity(amount));
  }
  
  public Quantity getCurrentValue() {
    return this.currentValue;
  }
  
  public A withCurrentValue(Quantity currentValue) {
    this.currentValue = currentValue;
    return (A) this;
  }
  
  public boolean hasCurrentValue() {
    return this.currentValue != null;
  }
  
  public A withNewCurrentValue(String amount,String format) {
    return (A)withCurrentValue(new Quantity(amount, format));
  }
  
  public A withNewCurrentValue(String amount) {
    return (A)withCurrentValue(new Quantity(amount));
  }
  
  public String getMetricName() {
    return this.metricName;
  }
  
  public A withMetricName(String metricName) {
    this.metricName = metricName;
    return (A) this;
  }
  
  public boolean hasMetricName() {
    return this.metricName != null;
  }
  
  public LabelSelector buildMetricSelector() {
    return this.metricSelector != null ? this.metricSelector.build() : null;
  }
  
  public A withMetricSelector(LabelSelector metricSelector) {
    this._visitables.remove("metricSelector");
    if (metricSelector != null) {
        this.metricSelector = new LabelSelectorBuilder(metricSelector);
        this._visitables.get("metricSelector").add(this.metricSelector);
    } else {
        this.metricSelector = null;
        this._visitables.get("metricSelector").remove(this.metricSelector);
    }
    return (A) this;
  }
  
  public boolean hasMetricSelector() {
    return this.metricSelector != null;
  }
  
  public MetricSelectorNested<A> withNewMetricSelector() {
    return new MetricSelectorNested(null);
  }
  
  public MetricSelectorNested<A> withNewMetricSelectorLike(LabelSelector item) {
    return new MetricSelectorNested(item);
  }
  
  public MetricSelectorNested<A> editMetricSelector() {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(null));
  }
  
  public MetricSelectorNested<A> editOrNewMetricSelector() {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public MetricSelectorNested<A> editOrNewMetricSelectorLike(LabelSelector item) {
    return withNewMetricSelectorLike(java.util.Optional.ofNullable(buildMetricSelector()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalMetricStatusFluent that = (ExternalMetricStatusFluent) o;
    if (!java.util.Objects.equals(currentAverageValue, that.currentAverageValue)) return false;
    if (!java.util.Objects.equals(currentValue, that.currentValue)) return false;
    if (!java.util.Objects.equals(metricName, that.metricName)) return false;
    if (!java.util.Objects.equals(metricSelector, that.metricSelector)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(currentAverageValue,  currentValue,  metricName,  metricSelector,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (currentAverageValue != null) { sb.append("currentAverageValue:"); sb.append(currentAverageValue + ","); }
    if (currentValue != null) { sb.append("currentValue:"); sb.append(currentValue + ","); }
    if (metricName != null) { sb.append("metricName:"); sb.append(metricName + ","); }
    if (metricSelector != null) { sb.append("metricSelector:"); sb.append(metricSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetricSelectorNested<N> extends LabelSelectorFluent<MetricSelectorNested<N>> implements Nested<N>{
    MetricSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) ExternalMetricStatusFluent.this.withMetricSelector(builder.build());
    }
    
    public N endMetricSelector() {
      return and();
    }
    
  
  }

}
